==> simsu-1.4.5.tar.bz2: simsu-1.4.5/translations/simsu_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Success</source>
        <translation>Succès</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Sélectionner la langue de l&apos;application</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Langue du système&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Remarque</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Veuillez relancer l&apos;application pour que la modification prenne effet. </translation>
    </message>
</context>
<context>
    <name>NewGamePage</name>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Create Your Own</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Pattern</name>
    <message>
        <source>180° Rotational</source>
        <translation>Rotation à 180°</translation>
    </message>
    <message>
        <source>Full Rotational</source>
        <translation>Rotation complète</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <source>Horizontal &amp; Vertical</source>
        <translation>Horizontal &amp; vertical</translation>
    </message>
    <message>
        <source>Diagonal</source>
        <translation>Diagonale</translation>
    </message>
    <message>
        <source>Anti-Diagonal</source>
        <translation>Anti-diagonale</translation>
    </message>
    <message>
        <source>Diagonal &amp; Anti-Diagonal</source>
        <translation>Diagonale &amp; anti-diagonale</translation>
    </message>
    <message>
        <source>Full Dihedral</source>
        <translation>Dièdre complet</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Aléatoire</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
</context>
<context>
    <name>Puzzle</name>
    <message>
        <source>Simple</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Easy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Medium</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hard</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Simsu</source>
        <translation>Simsu</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Stylo</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Crayon</translation>
    </message>
    <message>
        <source>Highlight</source>
        <translation>Surlignage</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jeu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Détails</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Déplacer</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Rétablir</translation>
    </message>
    <message>
        <source>&amp;Check</source>
        <translation>&amp;Vérifier</translation>
    </message>
    <message>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <source>&amp;Auto Switch Modes</source>
        <translation>Modes &amp;automatiques</translation>
    </message>
    <message>
        <source>&amp;Widescreen Layout</source>
        <translation>Mise en page pour écrans &amp;larges</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Langue de l&apos;application…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Commandes</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>À &amp;propos de…</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>À propos de &amp;Qt</translation>
    </message>
    <message>
        <source>Symmetry:</source>
        <translation>Symétrie : </translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Contrôles</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;big&gt;&lt;b&gt;Mouse Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Left click:&lt;/b&gt; Toggle number in pen mode&lt;br&gt;&lt;b&gt;Right click:&lt;/b&gt; Toggle number in pencil mode&lt;br&gt;&lt;b&gt;Scrollwheel:&lt;/b&gt; Change current number&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Keyboard Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Arrow keys:&lt;/b&gt; Move selection&lt;br&gt;&lt;b&gt;Number keys:&lt;/b&gt; Toggle value or note&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Switch between pen and pencil modes&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Highlight all instances of current number&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;big&gt;&lt;b&gt;Contrôle à la souris : &lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Clic gauche : &lt;/b&gt;bascule le nombre en mode stylo&lt;br&gt;&lt;b&gt;Clic droit : &lt;/b&gt;bascule le nombre en mode crayon&lt;br&gt;&lt;b&gt;Roulette : &lt;/b&gt;change le chiffre en cours&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Contrôle au clavier : &lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Touches de direction : &lt;/b&gt;déplace la sélection&lt;br&gt;&lt;b&gt;Touches numériques :&lt;/b&gt;bascule la valeur ou la note&lt;br&gt;&lt;b&gt;S : &lt;/b&gt; bascule entre les modes stylo et crayon&lt;br&gt;&lt;b&gt;H : &lt;/b&gt;Surligne toutes les occurences du nombre en cours&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About Simsu</source>
        <translation>À propos de Simsu</translation>
    </message>
    <message>
        <source>A basic Sudoku game</source>
        <translation>Un jeu de Sudoku simple</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publié sous licence &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have not created a valid puzzle. Please try again.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>F2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Manual Notes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto &amp;Clear Notes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto &amp;Fill Notes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset the board to its original state?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print Board</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Difficulty:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> simsu-1.4.6.tar.bz2: simsu-1.4.6/translations/simsu_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Success</source>
        <translation>Réussi</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Sélectionnez la langue de l&apos;application</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Langue du système&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Remarque</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Veuillez relancer l&apos;application pour que la modification prenne effet. </translation>
    </message>
</context>
<context>
    <name>NewGamePage</name>
    <message>
        <source>Play Game</source>
        <translation>Lancer un jeu</translation>
    </message>
    <message>
        <source>Create Your Own</source>
        <translation>Créez le vôtre</translation>
    </message>
</context>
<context>
    <name>Pattern</name>
    <message>
        <source>180° Rotational</source>
        <translation>Rotation à 180°</translation>
    </message>
    <message>
        <source>Full Rotational</source>
        <translation>Rotation complète</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <source>Horizontal &amp; Vertical</source>
        <translation>Horizontal &amp; vertical</translation>
    </message>
    <message>
        <source>Diagonal</source>
        <translation>Diagonal</translation>
    </message>
    <message>
        <source>Anti-Diagonal</source>
        <translation>Antidiagonal</translation>
    </message>
    <message>
        <source>Diagonal &amp; Anti-Diagonal</source>
        <translation>Diagonal &amp; antidiagonal</translation>
    </message>
    <message>
        <source>Full Dihedral</source>
        <translation>Dièdre complet</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Aléatoire</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Aucun</translation>
    </message>
</context>
<context>
    <name>Puzzle</name>
    <message>
        <source>Simple</source>
        <translation>Simple</translation>
    </message>
    <message>
        <source>Easy</source>
        <translation>Facile</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Moyen</translation>
    </message>
    <message>
        <source>Hard</source>
        <translation>Difficile</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Simsu</source>
        <translation>Simsu</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Stylo</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Crayon</translation>
    </message>
    <message>
        <source>Highlight</source>
        <translation>Surlignage</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>S</source>
        <translation>S</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jeu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Détails</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>&amp;Move</source>
        <translation>&amp;Entrée</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Défaire</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Rétablir</translation>
    </message>
    <message>
        <source>&amp;Check</source>
        <translation>&amp;Vérifier</translation>
    </message>
    <message>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <source>&amp;Auto Switch Modes</source>
        <translation>Modes commutation &amp;automatique</translation>
    </message>
    <message>
        <source>&amp;Widescreen Layout</source>
        <translation>Mise en page pour écrans &amp;larges</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Langue de l&apos;application…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Commandes</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>À &amp;propos de…</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>À propos de &amp;Qt</translation>
    </message>
    <message>
        <source>Symmetry:</source>
        <translation>Symétrie : </translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Détails</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Contrôles</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;big&gt;&lt;b&gt;Mouse Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Left click:&lt;/b&gt; Toggle number in pen mode&lt;br&gt;&lt;b&gt;Right click:&lt;/b&gt; Toggle number in pencil mode&lt;br&gt;&lt;b&gt;Scrollwheel:&lt;/b&gt; Change current number&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Keyboard Controls:&lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Arrow keys:&lt;/b&gt; Move selection&lt;br&gt;&lt;b&gt;Number keys:&lt;/b&gt; Toggle value or note&lt;br&gt;&lt;b&gt;S:&lt;/b&gt; Switch between pen and pencil modes&lt;br&gt;&lt;b&gt;H:&lt;/b&gt; Highlight all instances of current number&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;big&gt;&lt;b&gt;Contrôle à la souris : &lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Clic gauche : &lt;/b&gt;bascule le nombre en mode stylo&lt;br&gt;&lt;b&gt;Clic droit : &lt;/b&gt;bascule le nombre en mode crayon&lt;br&gt;&lt;b&gt;Roulette : &lt;/b&gt;change le chiffre en cours&lt;/p&gt;&lt;p&gt;&lt;big&gt;&lt;b&gt;Contrôle au clavier : &lt;/b&gt;&lt;/big&gt;&lt;br&gt;&lt;b&gt;Touches de direction : &lt;/b&gt;déplace la sélection&lt;br&gt;&lt;b&gt;Touches numériques :&lt;/b&gt;bascule la valeur ou la note&lt;br&gt;&lt;b&gt;S : &lt;/b&gt; bascule entre les modes stylo et crayon&lt;br&gt;&lt;b&gt;H : &lt;/b&gt;Surligne toutes les occurences du nombre en cours&lt;/p&gt;</translation>
    </message>
    <message>
        <source>About Simsu</source>
        <translation>À propos de Simsu</translation>
    </message>
    <message>
        <source>A basic Sudoku game</source>
        <translation>Un jeu de Sudoku simple</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publié sous licence &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Désolé</translation>
    </message>
    <message>
        <source>You have not created a valid puzzle. Please try again.</source>
        <translation>Vous n&apos;avez pas créé un puzzle correct. Veuillez réessayer. </translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Veuillez patienter. </translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Génération du puzzle en cours...</translation>
    </message>
    <message>
        <source>&amp;Restart</source>
        <translation>&amp;Relancer</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Im&amp;primer...</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>In&amp;dice</translation>
    </message>
    <message>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <source>&amp;Manual Notes</source>
        <translation>Notes &amp;manuelles</translation>
    </message>
    <message>
        <source>Auto &amp;Clear Notes</source>
        <translation>&amp;Nettoyage automatique des notes</translation>
    </message>
    <message>
        <source>Auto &amp;Fill Notes</source>
        <translation>R&amp;emplissage automatique des notes</translation>
    </message>
    <message>
        <source>Restart Game</source>
        <translation>Relance du jeu</translation>
    </message>
    <message>
        <source>Reset the board to its original state?</source>
        <translation>Réinitialiser la carte à son état d&apos;origine ? </translation>
    </message>
    <message>
        <source>Print Board</source>
        <translation>Imprimer la carte</translation>
    </message>
    <message>
        <source>Difficulty:</source>
        <translation>Difficulté : </translation>
    </message>
</context>
</TS>
